@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2013 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,12 +59,14 @@ import java.util.List;
 import java.util.Map;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
+import org.slf4j.Logger;
 import com.openexchange.ajax.container.FileHolder;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestDataTools;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.ajax.requesthandler.responseRenderers.FileResponseRenderer;
 import com.openexchange.exception.OXException;
+import com.openexchange.file.storage.File;
 import com.openexchange.file.storage.FileStorageExceptionCodes;
 import com.openexchange.file.storage.FileStorageFileAccess;
 import com.openexchange.file.storage.FileStorageUtility;
@@ -94,6 +96,8 @@ public class InfostoreFileServlet extends OnlinePublicationServlet {
 
     private static final long serialVersionUID = -7725853828283398968L;
 
+    private static final Logger LOGGER = org.slf4j.LoggerFactory.getLogger(InfostoreFileServlet.class);
+
     private static final String CONTEXTID = "contextId";
     private static final String SITE = "site";
     private static final String INFOSTORE_ID = "infoId";
@@ -119,6 +123,15 @@ public class InfostoreFileServlet extends OnlinePublicationServlet {
         fileResponseRenderer = renderer;
     }
 
+    // -------------------------------------------------------------------------------------------------------
+
+    /**
+     * Initializes a new {@link InfostoreFileServlet}.
+     */
+    public InfostoreFileServlet() {
+        super();
+    }
+
     @Override
     protected void service(final HttpServletRequest req, final HttpServletResponse resp) throws IOException {
         final Map<String, String> args = getPublicationArguments(req);
@@ -151,6 +164,21 @@ public class InfostoreFileServlet extends OnlinePublicationServlet {
             startedWriting = true;
             writeFile(new PublicationSession(publication), metadata, fileData, req, resp);
 
+        } catch (OXException e) {
+            if (PublicationErrorMessage.NOT_FOUND_EXCEPTION.equals(e)) {
+                // Signal 404 - Not found
+                String queryString = req.getQueryString();
+                LOGGER.debug("No such file for request: {}{}", req.getRequestURI(), null == queryString ? "" : "?" + queryString);
+                resp.sendError(HttpServletResponse.SC_NOT_FOUND);
+                return;
+            }
+
+            // Signal internal server error
+            resp.setStatus(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
+            if(!startedWriting) {
+                e.printStackTrace(resp.getWriter());
+            }
+            LOG.error("", e);
         } catch (Exception e) {
             resp.setStatus(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
             if(!startedWriting) {
@@ -171,9 +199,13 @@ public class InfostoreFileServlet extends OnlinePublicationServlet {
                 throw PublicationErrorMessage.NOT_FOUND_EXCEPTION.create();
             }
             Session session = new PublicationSession(publication);
-            IDBasedFileAccess fileAccess = factory.createAccess(session);
+            IDBasedFileAccess fileAccess = fileFactory.createAccess(session);
             String id = publication.getEntityId() + '/' + infoId;
-            return FileMetadata.getMetadata(fileAccess.getFileMetadata(id, FileStorageFileAccess.CURRENT_VERSION));
+            File metadata = fileAccess.getFileMetadata(id, FileStorageFileAccess.CURRENT_VERSION);
+            if (null == metadata || null != publication.getEntityId() && false == publication.getEntityId().equals(metadata.getFolderId())) {
+                throw PublicationErrorMessage.NOT_FOUND_EXCEPTION.create();
+            }
+            return FileMetadata.getMetadata(metadata);
         } catch (final OXException e) {
             if (InfostoreExceptionCodes.NOT_EXIST.equals(e) || FileStorageExceptionCodes.FILE_NOT_FOUND.equals(e)) {
                 throw PublicationErrorMessage.NOT_FOUND_EXCEPTION.create(e, new Object[0]);
